import com.intellij.openapi.vfs.VirtualFileListener;
import com.intellij.openapi.vfs.VirtualFilePropertyEvent;
import com.intellij.openapi.vfs.VirtualFileEvent;
import com.intellij.openapi.vfs.VirtualFileMoveEvent;

import java.io.File;
import java.util.List;
import java.util.Iterator;
import java.util.ArrayList;

/**
 * Monitors the file system for changes to the Maven project.xml or to the IntelliJ
 * module.
 *
 * @author Jeff Sabin
 */
public class FileChangeMonitor implements VirtualFileListener
{
    private File mavenProjectFile;
    private File moduleFile;
    private List listeners;

    public FileChangeMonitor(File mavenProjectFile, File moduleFile)
    {
        this.mavenProjectFile = mavenProjectFile;
        this.moduleFile = moduleFile;
        listeners = new ArrayList();
    }

    public void addListener(IFileChangedListener listener)
    {
        if (!listeners.contains(listener))
        {
            listeners.add(listener);
        }
    }

    private void notifyListenersOfChange(boolean moduleChanged)
    {
        for(Iterator iterator = listeners.iterator(); iterator.hasNext();)
        {
            IFileChangedListener listener = (IFileChangedListener)iterator.next();
            if (moduleChanged)
            {
                listener.intelliJModuleChanged();
            }
            else
            {
                listener.mavenProjectChanged();
            }
        }
    }

    private void notifyListenersOfCreate()
    {
        for(Iterator iterator = listeners.iterator(); iterator.hasNext();)
        {
            IFileChangedListener listener = (IFileChangedListener)iterator.next();
            listener.mavenProjectCreated(mavenProjectFile);
        }
    }

    public void propertyChanged(VirtualFilePropertyEvent event)
    {

    }

    public void contentsChanged(VirtualFileEvent event)
    {
        File changedFile = new File(event.getFile().getPath());
        if (changedFile.equals(mavenProjectFile))
        {
            notifyListenersOfChange(false);
        }
        else if (changedFile.equals(moduleFile))
        {
            notifyListenersOfChange(true);
        }
    }

    public void fileCreated(VirtualFileEvent event)
    {
        File changedFile = new File(event.getFile().getPath());
        if (changedFile.equals(mavenProjectFile))
        {
            notifyListenersOfCreate();
        }
    }

    public void fileDeleted(VirtualFileEvent event)
    {

    }

    public void fileMoved(VirtualFileMoveEvent event)
    {

    }

    public void beforePropertyChange(VirtualFilePropertyEvent event)
    {

    }

    public void beforeContentsChange(VirtualFileEvent event)
    {

    }

    public void beforeFileDeletion(VirtualFileEvent event)
    {

    }

    public void beforeFileMovement(VirtualFileMoveEvent event)
    {

    }
}
