import com.intellij.openapi.components.ProjectComponent;
import com.intellij.openapi.module.ModuleManager;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.ui.Messages;
import com.intellij.openapi.diagnostic.Logger;
import intellijmaven.core.IntelliJModule;
import intellijmaven.core.MavenProject;
import intellijmaven.core.Utilities;
import intellijmaven.tools.UpdateIntelliJModule;
import org.jdom.JDOMException;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

/**
 * @author Jeff Sabin
 */
public class MavenUpdatorComponent implements ProjectComponent, IFileChangedListener
{
    private static final Logger logger = Logger.getInstance(CompareDependencies.class.getName());

    private static final int YES = 0;
    private static final int NO = 1;

    private Project project;

    public MavenUpdatorComponent(Project project)
    {
        this.project = project;
    }

    public void initComponent()
    {
        // TODO: insert component initialization logic here
    }

    public void disposeComponent()
    {
        // TODO: insert component disposal logic here
    }

    public String getComponentName()
    {
        return "MavenUpdatorComponent";
    }

    public MavenProject getMavenProject() throws IOException, JDOMException
    {
        File projectFile = new File(project.getProjectFilePath());
        File mavenProjectFile = new File(projectFile.getParentFile(), "project.xml");
        if(!mavenProjectFile.exists())
        {
            logger.error("Maven project file does not exist: " + mavenProjectFile);
        }
        return new MavenProject(mavenProjectFile);
    }

    public IntelliJModule getModule() throws IOException, JDOMException
    {
        ModuleManager manager = ModuleManager.getInstance(project);
        // todo how to handle multiple modules?
        File moduleFile = new File(manager.getModules()[0].getModuleFilePath());
        return new IntelliJModule(moduleFile);
    }

    public void projectOpened()
    {
//        try
//        {
////            notifyUserOfDifferences();
//
//            // Register for file system events
//            FileChangeMonitor monitor = new FileChangeMonitor(getMavenProject().getProjectFile(),
//                    getModule().getModuleFile());
//            monitor.addListener(this);
//            VirtualFileSystem fileSystem = LocalFileSystem.getInstance();
//            fileSystem.addVirtualFileListener(monitor);
//        }
//        catch (Exception e)
//        {
//            logger.error("", e);
//        }
    }

    private void notifyUserOfDifferences() throws IOException, JDOMException
    {
        // check differences
        List differences = getDifferences();
        if(differences.size() > 0)
        {
            int choice = Messages.showYesNoDialog(project,
                    "Maven project.xml has been modified. Update IntelliJ dependencies?",
                    "Maven Updates", Messages.getInformationIcon());
            if(choice == YES)
            {
                try
                {
                    UpdateIntelliJModule.update(getModule(), getMavenProject());
                }
                catch (Exception e)
                {
                    logger.error("", e);
                }
            }
        }
    }

    private List getDifferences() throws IOException, JDOMException
    {
        MavenProject mavenProject = getMavenProject();
        IntelliJModule module = getModule();

        if(mavenProject == null || module == null)
        {
            return new ArrayList();
        }

        return Utilities.getMavenDependencyDifferences(mavenProject, module);
    }

    public void projectClosed()
    {
        // called when project is being closed
    }

    public void mavenProjectChanged()
    {
        try
        {
            notifyUserOfDifferences();
            Messages.showMessageDialog("Maven project changed has changed.", "Maven Project Changed", Messages.getInformationIcon());
        }
        catch (Exception e)
        {
            logger.error("", e);
        }
    }

    public void intelliJModuleChanged()
    {
        try
        {
            notifyUserOfDifferences();
            Messages.showMessageDialog("Module changed has changed.", "Module Changed", Messages.getInformationIcon());
        }
        catch (Exception e)
        {
            logger.error("", e);
        }
    }

    public void mavenProjectCreated(File mavenProjectFile)
    {
        try
        {
            notifyUserOfDifferences();
        }
        catch (Exception e)
        {
            logger.error("", e);
        }
    }
}
