import com.intellij.openapi.actionSystem.AnAction;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.actionSystem.DataConstants;
import com.intellij.openapi.actionSystem.DataContext;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.ui.Messages;
import com.intellij.openapi.vfs.LocalFileSystem;
import com.intellij.openapi.vfs.VirtualFileSystem;
import com.intellij.openapi.module.Module;
import com.intellij.openapi.module.ModuleManager;
import com.intellij.openapi.diagnostic.Logger;
import intellijmaven.tools.UpdateIntelliJModule;

/**
 * Remove all dependencies from the IDEA module file and add to it all dependencies found in the
 * Maven project file.
 *
 * @author Jeff Sabin
 */
public class UpdateIntelliJFromMavenAction extends AnAction
{
    private static final Logger logger = Logger.getInstance(CompareDependencies.class.getName());

    public void actionPerformed(AnActionEvent e)
    {
        DataContext dataContext = e.getDataContext();
        Project project = (Project)dataContext.getData(DataConstants.PROJECT);
        MavenUpdatorComponent component = project.getComponent(MavenUpdatorComponent.class);

        try
        {
            // Reload from disk. They may have already performed this operation but not told IntelliJ to reload it.
            // Prevents duplicates.
            reloadModule(project);

            UpdateIntelliJModule.update(component.getModule(), component.getMavenProject());

            // Cause IntelliJ to recognize the change and prompt user to reload.
            reloadModule(project);
        }
        catch (Exception e1)
        {
            logger.error("", e1);
            Messages.showMessageDialog("Could not update module.", "Update Failed", Messages.getErrorIcon());
        }
    }

    /**
     * Reload the module from disk.
     *
     * @param project project
     */
    private void reloadModule(Project project)
    {
        Module module = ModuleManager.getInstance(project).getModules()[0];
        VirtualFileSystem fileSystem = LocalFileSystem.getInstance();
        fileSystem.forceRefreshFile(module.getModuleFile());
    }
}
