import com.intellij.openapi.actionSystem.AnAction;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.actionSystem.DataConstants;
import com.intellij.openapi.actionSystem.DataContext;
import com.intellij.openapi.diagnostic.Logger;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.ui.Messages;
import com.intellij.openapi.vfs.LocalFileSystem;
import intellijmaven.tools.UpdateMavenProject;
import org.jdom.JDOMException;

import java.io.IOException;

/**
 * Rebuilds the Maven dependency list in the project.xml from the dependency list of the IntelliJ
 * module.
 *
 * @author Jeff Sabin
 */
public class UpdateMavenFromIntelliJModuleAction extends AnAction
{
    private static final Logger logger = Logger.getInstance(CompareDependencies.class.getName());

    public void actionPerformed(AnActionEvent e)
    {
        DataContext dataContext = e.getDataContext();
        Project project = (Project)dataContext.getData(DataConstants.PROJECT);
        MavenUpdatorComponent component = project.getComponent(MavenUpdatorComponent.class);

        try
        {
            reloadMavenProject(component); // Ensure that the we have read the latest
            UpdateMavenProject.update(component.getModule(), component.getMavenProject());
            reloadMavenProject(component); // Tell IntelliJ to reload from disk so we have the latest in the editor

            Messages.showMessageDialog("Maven project succefully updated.", "Update Succeeded", Messages.getInformationIcon());
        }
        catch (Exception e1)
        {
            logger.error("", e1);
            Messages.showMessageDialog("Could not update project. " + e1, "Update Failed", Messages.getErrorIcon());
        }
    }

    /**
     * Reloads the project.xml file from disk.
     *
     * @param component
     * @throws IOException
     * @throws JDOMException
     */
    private void reloadMavenProject(MavenUpdatorComponent component)
            throws IOException, JDOMException
    {

        LocalFileSystem fileSystem = LocalFileSystem.getInstance();
        fileSystem.refreshAndFindFileByIoFile(component.getMavenProject().getProjectFile());
//        VirtualFile projectFile = fileSystem.refreshAndFindFileByIoFile(component.getMavenProject().getProjectFile());
//        fileSystem.forceRefreshFile(projectFile);
    }
}
