package intellijmaven.core;

/**
 * Represents a dependency.
 * 
 * @author Jeff Sabin
 */
public class Dependency implements IDependency
{
    private String version;
    private String artifactId;
    private String groupId;
    private String libraryName;
    private IIntelliJUrl url;

    /**
     * Creates a dependency.
     *
     * @param intelliJUrl path of the module of the form
     * "jar://C:/Documents and Settings/jsabin/.maven/repository/groupId/common-1.2-SNAPSHOT.jar!/"
     */
    public Dependency(String libraryName, IIntelliJUrl intelliJUrl)
    {
        this.libraryName = libraryName;
        this.url = intelliJUrl;

        artifactId = libraryName;
        groupId = url.getGroupId();
        version = url.getVersion();
    }

    /**
     * Create a dependency from Maven dependency pieces.
     *
     * @param groupId
     * @param artifactId
     * @param version
     */
    public Dependency(String groupId, String artifactId, String version)
    {
        this.version = version;
        this.artifactId = artifactId;
        this.groupId = groupId;
        this.libraryName = artifactId;
        this.url = new IntelliJUrl("jar://" + Utilities.getMavenRepository() + "/" + groupId +
                "/jars/" + artifactId + "-" + version + ".jar!/");
    }

    public String getGroupId()
    {
        return groupId;
    }

    public String getVersion()
    {
        return version;
    }

    public String getArtifactId()
    {
        return artifactId;
    }

    public String getLibraryName()
    {
        return libraryName;
    }

    public IIntelliJUrl getUrl()
    {
        return url;
    }

    public boolean equals(Object o)
    {
        if(this == o)
        {
            return true;
        }
        if(o == null || getClass() != o.getClass())
        {
            return false;
        }

        final Dependency that = (Dependency)o;

        if(artifactId != null ? !artifactId.equals(that.artifactId) : that.artifactId != null)
        {
            return false;
        }
        if(groupId != null ? !groupId.equals(that.groupId) : that.groupId != null)
        {
            return false;
        }
        if(libraryName != null ? !libraryName.equals(that.libraryName) : that.libraryName != null)
        {
            return false;
        }
        if(version != null ? !version.equals(that.version) : that.version != null)
        {
            return false;
        }

        return true;
    }

    public int hashCode()
    {
        int result;
        result = (version != null ? version.hashCode() : 0);
        result = 29 * result + (artifactId != null ? artifactId.hashCode() : 0);
        result = 29 * result + (groupId != null ? groupId.hashCode() : 0);
        result = 29 * result + (libraryName != null ? libraryName.hashCode() : 0);
        result = 29 * result + (url != null ? url.hashCode() : 0);
        return result;
    }


    public String toString()
    {
        return "intellijmaven.core.Dependency{" +
                "version='" + version + '\'' +
                ", artifactId='" + artifactId + '\'' +
                ", groupId='" + groupId + '\'' +
                ", libraryName='" + libraryName + '\'' +
                ", url=" + url +
                '}';
    }
}
