package intellijmaven.core;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

/**
 * Set of utilities for Maven project files and IntelliJ modules.
 *
 * @author Jeff Sabin
 */
public class Utilities
{
    public static String getMavenRepository()
    {
        String userHomeDir = System.getProperty("user.home");
        String mavenRepository = userHomeDir + "/.maven/repository";

        // replace backslashes with forward slashes. IntelliJ is very particular about this
        mavenRepository = mavenRepository.replace('\\', '/');

        return mavenRepository;
    }

    /**
     * Returns a list of dependencies found in the Maven project.xml not found in the IntelliJ
     * modules.
     *
     * @return list of dependencies unique to the Maven project.xml.
     */
    public static List getMavenDependencyDifferences(IMavenProject project, IntelliJModule module)
    {
        List differences = new ArrayList();

        List maven = project.getDependencies();
        for(Iterator iterator = maven.iterator(); iterator.hasNext();)
        {
            Dependency mavenDependency = (Dependency)iterator.next();

            boolean found = false;
            List intellij = module.getDependencies();
            for(Iterator iterator1 = intellij.iterator(); iterator1.hasNext();)
            {
                IDependency intelliJDependency = (IDependency)iterator1.next();
                if (mavenDependency.equals(intelliJDependency))
                {
                    // intellijmaven.core.Dependency found, check the next one.
                    found = true;
                    break;
                }
                // todo check for one that's the same but has a different version
            }
            if (!found)
            {
                differences.add(mavenDependency);
            }
        }
        return differences;
    }

    /**
     * Returns a list of dependencies found in the IntelliJ module file that is not found
     * in the Maven project.xml.
     *
     * @return list of dependencies unique to the IntelliJ module.
     */
    public static List getIntelliJDependencyDifferences(IMavenProject project, IntelliJModule module)
    {
        List differences = new ArrayList();

        List intellij = module.getDependencies();
        for(Iterator iterator = intellij.iterator(); iterator.hasNext();)
        {
            Dependency intellijDependency = (Dependency)iterator.next();

            boolean found = false;
            List maven = project.getDependencies();
            for(Iterator iterator1 = maven.iterator(); iterator1.hasNext();)
            {
                IDependency mavenDependency = (IDependency)iterator1.next();
                if (intellijDependency.equals(mavenDependency))
                {
                    // intellijmaven.core.Dependency found, check the next one.
                    found = true;
                    break;
                }
                // todo check for one that's the same but has a different version
            }
            if (!found)
            {
                differences.add(intellijDependency);
            }
        }
        return differences;
    }
}
