package intellijmaven.tools;

import intellijmaven.core.Dependency;
import intellijmaven.core.IMavenProject;
import intellijmaven.core.IntelliJModule;
import intellijmaven.core.MavenProject;
import org.jdom.JDOMException;

import java.io.File;
import java.io.IOException;
import java.util.Iterator;
import java.util.List;

/**
 * Removes all dependencies from the Maven project.xml and replaces them with all dependencies found
 * in the IntelliJ module.
 *
 * @author Jeff Sabin
 */
public class UpdateMavenProject
{
    public static void update(File moduleFile, File projectFile) throws IOException, JDOMException
    {
        IntelliJModule module = new IntelliJModule(moduleFile);
        IMavenProject project = new MavenProject(projectFile, module.isWebModule());
        update(module, project);
    }

    public static void update(IntelliJModule module, IMavenProject project) throws IOException, JDOMException
    {
        project.removeAllDependencies();

        List dependencies = module.getDependencies();
        for(Iterator iterator = dependencies.iterator(); iterator.hasNext();)
        {
            Dependency dependency = (Dependency)iterator.next();
            project.addDependency(dependency);
        }

        project.save();
    }

    private static void help()
    {
        System.out.println("\nUpdateMavenProject syncs your Maven project.xml file with the IntelliJ 5.0 module (.iml) file. " +
                "It removes existing dependencies and re-adds them based on your IntelliJ 5.0 module " +
                "file.\n");
        System.out.println("Usage: java -classpath classes;lib/jdom.jar intellijmaven.tools.UpdateMavenProject <projectXMLPath> <ideadModulePath>\n");
        System.out.println("\twhere");
        System.out.println("\t<projectXMLPath> is the path to the Maven project.xml file.\n");
        System.out.println("\t<ideadModulePath> is the path to the IntelliJ module file (.iml).\n");

    }

    public static void main(String[] args) throws Exception
    {
        if (args.length < 1)
        {
            help();
        }
        else
        {
            File projectFile = new File(args[0]);
            if (!projectFile.exists())
            {
                System.err.println("Maven project xml file does not exist: " + projectFile.getAbsolutePath() + "\n\n");
                help();
                System.exit(1);
            }

            File moduleFile = new File(args[1]);
            if (!projectFile.exists())
            {
                System.err.println("Module file does not exist: " + moduleFile.getAbsolutePath() + "\n\n");
                help();
                System.exit(1);
            }

            UpdateMavenProject.update(moduleFile, projectFile);
        }
    }

}
